@@ -11,7 +11,10 @@ from .logging import get_logger
 
 class CPZAIClient:
     """Client for accessing CPZ AI database (strategies and files)"""
-    
+
+    # Default platform REST URL (not configurable via env for end-users)
+    DEFAULT_API_URL = "https://api.cpz-lab.com/cpz-ai"
+
     def __init__(self, url: str, api_key: str, secret_key: str, user_id: str = None, is_admin: bool = False) -> None:
         self.url = url.rstrip("/")
         self.api_key = api_key
@@ -23,13 +26,19 @@ class CPZAIClient:
     @staticmethod
     def from_env(environ: Optional[Mapping[str, str]] = None) -> "CPZAIClient":
         env = environ or os.environ
-        url = env.get("CPZ_AI_URL", "https://api.cpz-lab.com/cpz-ai/v1")
+        # URL is fixed by SDK; do not require env variable
+        url = CPZAIClient.DEFAULT_API_URL
         api_key = env.get("CPZ_AI_API_KEY", "")
         secret_key = env.get("CPZ_AI_SECRET_KEY", "")
         user_id = env.get("CPZ_AI_USER_ID", "")
         is_admin = env.get("CPZ_AI_IS_ADMIN", "false").lower() == "true"
         return CPZAIClient(url=url, api_key=api_key, secret_key=secret_key, user_id=user_id, is_admin=is_admin)
 
+    @staticmethod
+    def from_keys(api_key: str, secret_key: str, user_id: Optional[str] = None, is_admin: bool = False) -> "CPZAIClient":
+        """Create client from keys only, using built-in default URL."""
+        return CPZAIClient(url=CPZAIClient.DEFAULT_API_URL, api_key=api_key, secret_key=secret_key, user_id=user_id or "", is_admin=is_admin)
+
     def _headers(self) -> dict[str, str]:
         return {
             "apikey": self.secret_key,  # Use service role key for full access
@@ -436,6 +445,96 @@ class CPZAIClient:
         except Exception as exc:  # noqa: BLE001
             return {"status": 0, "ok": False, "error": str(exc)}
 
+    # --- Trading & Credentials ---
+    def get_broker_credentials(self, broker: str = "alpaca", env: Optional[str] = None) -> Optional[Dict[str, str]]:
+        """Fetch broker trading credentials from CPZ AI using the service key.
+
+        Tries a few common table/field shapes to maximize compatibility without
+        hard-coding a single schema. Returns a dict with keys
+        {"api_key_id", "api_secret_key", "env"} if found, else None.
+        """
+        try:
+            # Normalize inputs
+            broker = (broker or "").strip().lower()
+            env_norm = (env or "").strip().lower() or None
+
+            # Candidate tables and param shapes to try in order
+            candidate_tables = [
+                "broker_credentials",
+                "alpaca_credentials",
+                "execution_credentials",
+            ]
+            candidate_broker_param_keys = ["broker", "broker_name", "name"]
+            candidate_env_param_keys = ["env", "environment", "mode"]
+
+            def _extract_creds(row: Dict[str, Any]) -> Optional[Dict[str, str]]:
+                # Handle a variety of likely field names
+                key_id_fields = ["api_key_id", "api_key", "key_id", "key"]
+                secret_fields = ["api_secret_key", "api_secret", "secret_key", "secret"]
+                env_fields = ["env", "environment", "mode"]
+
+                api_key_id: Optional[str] = None
+                api_secret_key: Optional[str] = None
+                env_value: Optional[str] = None
+
+                for k in key_id_fields:
+                    if k in row and row[k]:
+                        api_key_id = str(row[k])
+                        break
+                for k in secret_fields:
+                    if k in row and row[k]:
+                        api_secret_key = str(row[k])
+                        break
+                for k in env_fields:
+                    if k in row and row[k]:
+                        env_value = str(row[k])
+                        break
+
+                if api_key_id and api_secret_key:
+                    return {
+                        "api_key_id": api_key_id,
+                        "api_secret_key": api_secret_key,
+                        "env": (env_norm or (env_value or "paper")).lower(),
+                    }
+                return None
+
+            headers = self._headers()
+
+            for table in candidate_tables:
+                # Try several param shapes per table
+                for bkey in candidate_broker_param_keys:
+                    params: Dict[str, str] = {"select": "*"}
+                    params[bkey] = f"eq.{broker}"
+                    # Try with and without env filter
+                    env_keys_to_try = candidate_env_param_keys if env_norm else []
+
+                    # First, try with env if provided
+                    for ekey in env_keys_to_try:
+                        params_env = dict(params)
+                        params_env[ekey] = f"eq.{env_norm}"
+                        resp = requests.get(
+                            f"{self.url}/rest/v1/{table}", headers=headers, params=params_env, timeout=10
+                        )
+                        if resp.status_code == 200 and isinstance(resp.json(), list) and resp.json():
+                            creds = _extract_creds(resp.json()[0])
+                            if creds:
+                                return creds
+
+                    # Then, try without env (let server-side default apply)
+                    resp = requests.get(
+                        f"{self.url}/rest/v1/{table}", headers=headers, params=params, timeout=10
+                    )
+                    if resp.status_code == 200 and isinstance(resp.json(), list) and resp.json():
+                        creds = _extract_creds(resp.json()[0])
+                        if creds:
+                            return creds
+
+            # Not found
+            return None
+        except Exception as exc:  # noqa: BLE001
+            self.logger.error("cpz_ai_get_broker_credentials_error", error=str(exc))
+            return None
+
 
 # Legacy alias for backward compatibility (will be removed in future versions)
 # Use CPZAIClient instead
